--[[
	Name: HideLooted
	Author: Pneumatus
	Description: 
		Suppress chat messages when specified items are looted
]]--

local HideLooted = LibStub("AceAddon-3.0"):NewAddon("HideLooted", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("HideLooted")

--[===[@debug@
L["HL_LOOT_ITEM"] = ".* receives loot: .*item:(%d+)"
L["HL_LOOT_ITEM_CREATED"] = ".* creates: .*item:(%d+)"
--@end-debug@]===]

HideLooted.options = {
	name = "HideLooted",
	handler = HideLooted,
	type = 'group',
	args = {
		add = {
			type = 'input',
			name = L["Add"],
			desc = L["Add an item to be hidden"],
			set = function(info, val) 
				info.handler.db.profile.items[tonumber(val:match("item:(%d+)"))] = true 
			end,
			get = false,
			pattern = "item:%d+",
		},
		del = {
			type = 'input',
			name = L["Delete"],
			desc = L["Stop an item being hidden"],
			set = function(info, val) 
				local itemID = tonumber(val:match("item:(%d+)"))
				info.handler.db.profile.items[itemID] = nil or info.handler.defaults.profile.items[itemID] and false
			end,
			get = false,
			pattern = "item:%d+",
		},
		list = {
			type = 'execute',
			name = L["List"],
			desc = L["List all hidden items"],
			func = "ListHidden",
		},
		reset = {
			type = 'execute',
			name = L["Reset"],
			desc = L["Reset hidden items to the default list"],
			func = function(info)
				for k, _ in pairs(info.handler.db.profile.items) do 
					info.handler.db.profile.items[k] = info.handler.defaults.profile.items[k] 
				end
			end,
		},
	},
}

HideLooted.defaults = {
	profile = {
		items = {
			[20558] = true,		-- Warsong Gulch Mark of Honor
			[20559] = true,		-- Arathi Basin Mark of Honor
			[20560] = true,		-- Alterac Valley Mark of Honor
			[29024] = true,		-- Eye of the Storm Mark of Honor
			[29434] = true,		-- Badge of Justice
			[40752] = true,		-- Emblem of Heroism
			[40753] = true,		-- Emblem of Valor
			[42425] = true,		-- Strand of the Ancients Mark of Honor
			[43228] = true,		-- Stone Keeper's Shard
			[43589] = true,		-- Wintergrasp Mark of Honor
		},
	},
}

local function FilterLoot(msg)
	return HideLooted.db.profile.items[tonumber(msg:match(L["HL_LOOT_ITEM"]) or msg:match(L["HL_LOOT_ITEM_CREATED"]))]
end

function HideLooted:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("HideLootedDB", self.defaults)
	LibStub("AceConfig-3.0"):RegisterOptionsTable(self.name, self.options, {"hl", "hidelooted"})
end

function HideLooted:OnEnable()
	ChatFrame_AddMessageEventFilter("CHAT_MSG_LOOT", FilterLoot)
end

function HideLooted:OnDisable()
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_LOOT", FilterLoot)
end

function HideLooted:ListHidden()
	self:Print(L["Loot items currently being hidden:"])
	for itemID, show in pairs(self.db.profile.items) do
		if show then
			_, itemLink, _, _, _, _, _, _, _, _ = GetItemInfo(itemID)
			self:Print(itemLink)
		end
	end
end
